===============================
Text Toolkit: txttk
===============================

.. image:: https://img.shields.io/travis/jeroyang/txttk.svg
        :target: https://travis-ci.org/jeroyang/txttk

.. image:: https://img.shields.io/pypi/v/txttk.svg
        :target: https://pypi.python.org/pypi/txttk


Text Toolkit: manipulate text & regular expression

installation
------------

.. code:: bash

    $ pip install txttk

Usage
-----

To use txttk in a project:

.. code:: python

    from txttk import nlptools
    from txttk import retools
    from txttk import feature

Features
--------
* nlptools: Nature Language Processing tools.
* retools: Manipulate Regular Expression strings.
* feature: Extract features from a given token

License
---------
* Free software: BSD license
* Documentation: https://txttk.readthedocs.org.
